ControllerPublisher<T> class mixin

A mixin that provides a mechanism for subscribing to a controller.

This mixin is intended to be used with a controller class that extends

Constructors

ControllerPublisher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(ControllerSubscriber<T> listener) → void
Adds a listener to the list of listeners.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifySubscribers([dynamic value]) → void
Notifies all the registered listeners of a change to the value.
removeListener(ControllerSubscriber<T> listener) → void
Removes a listener from the list of listeners.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited