notifySubscribers method
void
notifySubscribers([
- dynamic value
Notifies all the registered listeners of a change to the value.
This method is a wrapper around ControllerWatcher.notifyListeners.
value is the value to be passed to the listeners.
Implementation
void notifySubscribers([dynamic value]) {
_watcher.notifyListeners(value);
}